/* daemonProgram.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "daemonProgram.h"
#include "format.h"

#include <unistd.h>


DaemonProgram::
DaemonProgram(const string &program_name) : DatabaseProgram(program_name) 
{
  define_opt("nofork", false);
  _nofork = false;
}

void DaemonProgram::
run() {
  if (_nofork) {
    cerr << _program_name << " running.\n";
    run_daemon();

  } else {
    pid_t child = fork();
    if (child < 0) {
      perror("fork");
      exit(1);
    }
    
    if (child == 0) {
      // child
      run_daemon();
      
    } else {
      // parent
      
      // We write this message as a single string, so it won't get
      // interrupted by possible messages from the child.
      cerr << _program_name << " forked, pid is " + format_int(child) + "\n";
    }
  }
}

void DaemonProgram::
handle_opts(const string &opt, const string &arg) {
  if (opt == "nofork") {
    _nofork = true;

  } else {    
    DatabaseProgram::handle_opts(opt, arg);
  }
}

void DaemonProgram::
describe_options() {
  cerr <<
    "  -nofork    Don't fork as a daemon, but run in the foreground.\n";
  DatabaseProgram::describe_options();
}
