/* infoMessage.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "infoMessage.h"
#include "gtkProgram.h"

InfoMessage::
InfoMessage(const string &message, int buttons, const string &check_text) :
  PalomaDialog(Dataset()),
  _label(message),
  _check(check_text),
  _check_align(0.5, 0.5, 0, 0),
  _ok_button("OK"),
  _cancel_button("Cancel")
{
  layout_window(buttons);
  setup();
}

InfoMessage::
~InfoMessage() {
}

void InfoMessage::
ok_button_clicked() {
  ok_clicked(this);
  delete_self();
}

void InfoMessage::
cancel_button_clicked() {
  cancel_clicked(this);
  delete_self();
}

void InfoMessage::
layout_window(int buttons) {
  set_title("Info");

  vbox_.pack_start(_box1);
  _box1.show();
  _box1.set_border_width(8);

  _box1.pack_start(_label);
  _label.show();

  if (buttons & IM_check) {
    // The check button.
    _box1.pack_start(_check_align, true, true, 16);
    _check_align.show();
    _check_align.add(_check);
    _check.show();
  }

  if (buttons & IM_ok) {
    // The OK button.
    _ok_button.set_usize(80, 36);
    action_area_.pack_start(_ok_button, true, false, 0);
    _ok_button.set_flags(GTK_CAN_DEFAULT);
    _ok_button.grab_default();
    _ok_button.show();
    connect_to_method(_ok_button.clicked, this, &ok_button_clicked);
  }

  if (buttons & IM_cancel) {
    // The Cancel button.
    _cancel_button.set_usize(80, 36);
    action_area_.pack_start(_cancel_button, true, false, 0);
    _cancel_button.set_flags(GTK_CAN_DEFAULT);
    _cancel_button.show();
    connect_to_method(_cancel_button.clicked, this, &cancel_button_clicked);
  }
}
