/* postgresQueryResult.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#ifdef USE_PGSQL

#include "postgresQueryResult.h"
#include "postgresDatabase.h"
#include "dataCell.h"
#include "string_utils.h"

PostgresQueryResult::
PostgresQueryResult(PostgresDatabase &db) : QueryResultBase(db) { 
  _pg_result = NULL;
}

PostgresQueryResult::
~PostgresQueryResult() {
  set_pg_result(NULL);
}

bool PostgresQueryResult::
success() const {
  return (_pg_result != NULL);
}

string PostgresQueryResult::
get_error_message() const {
  return _error_message;
}

int PostgresQueryResult::
get_num_columns() const {
  return (_pg_result == NULL) ? 0 : PQnfields(_pg_result);
}

string PostgresQueryResult::
get_column_name(int c) const {
  assert(_pg_result != NULL);
  return PQfname(_pg_result, c); 
}

DataCell::Type PostgresQueryResult::
get_column_type(int c) const {
  return get_db().get_type(PQftype(_pg_result, c));
}

int PostgresQueryResult::
get_num_rows() const {
  return (_pg_result == NULL) ? 0 : PQntuples(_pg_result);
}

DataCell PostgresQueryResult::
get_cell(int r, int c) const {
  assert(_pg_result != NULL);
  if (PQgetisnull(_pg_result, r, c)) {
    return DataCell();
  } else {
    return DataCell(PQgetvalue(_pg_result, r, c), get_column_type(c));
  }
}

// This returns the value of the indicated cell as a raw C-style
// string, or the NULL pointer if the cell value is NULL.  It's
// necessary for exactly one purpose: to retrieve a cell value before
// the Postgres type database has been built up.
const char *PostgresQueryResult::
get_cell_raw(int r, int c) const {
  assert(_pg_result != NULL);
  if (PQgetisnull(_pg_result, r, c)) {
    return NULL;
  } else {
    return PQgetvalue(_pg_result, r, c);
  }
}
  


void PostgresQueryResult::
set_pg_result(PGresult *result) {
  if (_pg_result != NULL) {
    PQclear(_pg_result);
    _pg_result = NULL;
  }
  _pg_result = result;
}

void PostgresQueryResult::
set_error_message(const string &msg) {
  _error_message = trim_blanks(msg);
}

#endif // USE_PGSQL


